==> rheolef_6.5.orig.tar.gz: rheolef-6.5/doc/pexamples/stokes_taylor_dg.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
GEODIR=${TOP_SRCDIR}/nfem/ptst
NPROC_MAX=${NPROC_MAX-"2"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

#echo "      not yet (skipped)"
#exit 0

status=0
run "$TOP_SRCDIR/nfem/sbin/mkgeo_grid_2d -t 10 -v4 2>/dev/null | $TOP_SRCDIR/nfem/pbin/geo -upgrade - > mesh-2d-t.geo 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "$TOP_SRCDIR/nfem/sbin/mkgeo_grid_2d -q 10 -v4 2>/dev/null | $TOP_SRCDIR/nfem/pbin/geo -upgrade - > mesh-2d-q.geo 2>/dev/null"
if test $? -ne 0; then status=1; fi

# geo          		approx  tolerance (err_linf max(u,p))
L="
mesh-2d-t		P1d	3e-1
mesh-2d-t		P2d	4e-2
mesh-2d-t		P3d	3e-3
mesh-2d-q		P1d	2e-0
mesh-2d-q		P2d	5e-1
mesh-2d-q		P3d	6e-3
"

while test "$L" != ""; do
  geo=`echo $L | awk '{print $1}'`
  approx=`echo $L | awk '{print $2}'`
  tol=`echo $L | awk '{print $3}'`
  L=`echo $L | awk '{for (i=4; i <= NF; i++) print $i}'`
  loop_mpirun "./stokes_taylor_dg $geo $approx 2>/dev/null | RHEOPATH=.:$GEODIR \$RUN ./stokes_taylor_error_dg $tol >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done
run "rm -f mesh-2d-t.geo mesh-2d-q.geo"
exit $status

==> rheolef_6.7.orig.tar.gz: rheolef-6.7/doc/pexamples/stokes_taylor_dg.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
GEODIR=${TOP_SRCDIR}/nfem/ptst
SBINDIR="../../nfem/sbin"
BINDIR="../../nfem/pbin"
NPROC_MAX=${NPROC_MAX-"2"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

#echo "      not yet (skipped)"
#exit 0

status=0
run "$SBINDIR/mkgeo_grid_2d -t 10 -v4 2>/dev/null | $BINDIR/geo -upgrade - > mesh-2d-t.geo 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "$SBINDIR/mkgeo_grid_2d -q 10 -v4 2>/dev/null | $BINDIR/geo -upgrade - > mesh-2d-q.geo 2>/dev/null"
if test $? -ne 0; then status=1; fi

# geo          		approx  tolerance (err_linf max(u,p))
L="
mesh-2d-t		P1d	3e-1
mesh-2d-t		P2d	4e-2
mesh-2d-t		P3d	3e-3
mesh-2d-q		P1d	2e-0
mesh-2d-q		P2d	5e-1
mesh-2d-q		P3d	6e-3
"

while test "$L" != ""; do
  geo=`echo $L | awk '{print $1}'`
  approx=`echo $L | awk '{print $2}'`
  tol=`echo $L | awk '{print $3}'`
  L=`echo $L | awk '{for (i=4; i <= NF; i++) print $i}'`
  loop_mpirun "./stokes_taylor_dg $geo $approx 2>/dev/null | RHEOPATH=.:$GEODIR \$RUN ./stokes_taylor_error_dg $tol >/dev/null 2>/dev/null"
  if test $? -ne 0; then status=1; fi
done
run "rm -f mesh-2d-t.geo mesh-2d-q.geo"
exit $status
